@@ -5,6 +5,7 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestSlice(t *testing.T) {
@@ -66,7 +67,7 @@ func TestDict(t *testing.T) {
 
 func TestKeys(t *testing.T) {
 	_, err := Keys()
-	assert.Error(t, err)
+	require.Error(t, err)
 
 	in := map[string]interface{}{
 		"foo": 1,
@@ -74,7 +75,7 @@ func TestKeys(t *testing.T) {
 	}
 	expected := []string{"bar", "foo"}
 	keys, err := Keys(in)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.EqualValues(t, expected, keys)
 
 	in2 := map[string]interface{}{
@@ -83,7 +84,7 @@ func TestKeys(t *testing.T) {
 	}
 	expected = []string{"bar", "foo", "baz", "qux"}
 	keys, err = Keys(in, in2)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.EqualValues(t, expected, keys)
 
 	in3 := map[string]interface{}{
@@ -94,13 +95,13 @@ func TestKeys(t *testing.T) {
 	}
 	expected = []string{"bar", "foo", "baz", "qux", "Bar", "Foo", "bar", "foo"}
 	keys, err = Keys(in, in2, in3)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.EqualValues(t, expected, keys)
 }
 
 func TestValues(t *testing.T) {
 	_, err := Values()
-	assert.Error(t, err)
+	require.Error(t, err)
 
 	in := map[string]interface{}{
 		"foo": 1,
@@ -108,7 +109,7 @@ func TestValues(t *testing.T) {
 	}
 	expected := []interface{}{2, 1}
 	values, err := Values(in)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.EqualValues(t, expected, values)
 
 	in2 := map[string]interface{}{
@@ -117,7 +118,7 @@ func TestValues(t *testing.T) {
 	}
 	expected = []interface{}{2, 1, 3, 4}
 	values, err = Values(in, in2)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.EqualValues(t, expected, values)
 
 	in3 := map[string]interface{}{
@@ -128,73 +129,73 @@ func TestValues(t *testing.T) {
 	}
 	expected = []interface{}{2, 1, 3, 4, 6, 5, 8, 7}
 	values, err = Values(in, in2, in3)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.EqualValues(t, expected, values)
 }
 
 func TestAppend(t *testing.T) {
 	out, err := Append(42, []interface{}{})
-	assert.NoError(t, err)
-	assert.EqualValues(t, out, []interface{}{42})
+	require.NoError(t, err)
+	assert.EqualValues(t, []interface{}{42}, out)
 
 	out, err = Append(42, []interface{}{4.9, false, "foo"})
-	assert.NoError(t, err)
-	assert.EqualValues(t, out, []interface{}{4.9, false, "foo", 42})
+	require.NoError(t, err)
+	assert.EqualValues(t, []interface{}{4.9, false, "foo", 42}, out)
 
 	// a strange but valid use-cases, since we're converting to an []interface{}
 	out, err = Append(42, []string{"foo"})
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.EqualValues(t, []interface{}{"foo", 42}, out)
 
 	out, err = Append("baz", []string{"foo", "bar"})
-	assert.NoError(t, err)
-	assert.EqualValues(t, out, []interface{}{"foo", "bar", "baz"})
+	require.NoError(t, err)
+	assert.EqualValues(t, []interface{}{"foo", "bar", "baz"}, out)
 }
 
 func TestPrepend(t *testing.T) {
 	out, err := Prepend(42, []interface{}{})
-	assert.NoError(t, err)
-	assert.EqualValues(t, out, []interface{}{42})
+	require.NoError(t, err)
+	assert.EqualValues(t, []interface{}{42}, out)
 
 	out, err = Prepend(42, []interface{}{4.9, false, "foo"})
-	assert.NoError(t, err)
-	assert.EqualValues(t, out, []interface{}{42, 4.9, false, "foo"})
+	require.NoError(t, err)
+	assert.EqualValues(t, []interface{}{42, 4.9, false, "foo"}, out)
 
 	// a strange but valid use-cases, since we're converting to an []interface{}
 	out, err = Prepend(42, []string{"foo"})
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.EqualValues(t, []interface{}{42, "foo"}, out)
 
 	out, err = Prepend("foo", []string{"bar", "baz"})
-	assert.NoError(t, err)
-	assert.EqualValues(t, out, []interface{}{"foo", "bar", "baz"})
+	require.NoError(t, err)
+	assert.EqualValues(t, []interface{}{"foo", "bar", "baz"}, out)
 }
 
 func TestUniq(t *testing.T) {
 	out, err := Uniq([]interface{}{1, 2, 3, 1, true, false, true, "1", 2})
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.EqualValues(t, []interface{}{1, 2, 3, true, false, "1"}, out)
 
 	out, err = Uniq([]string{"one", "two", "one", "three"})
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.EqualValues(t, []interface{}{"one", "two", "three"}, out)
 }
 
 func TestReverse(t *testing.T) {
 	out, err := Reverse([]interface{}{})
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.EqualValues(t, []interface{}{}, out)
 
 	out, err = Reverse([]interface{}{8})
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.EqualValues(t, []interface{}{8}, out)
 
 	out, err = Reverse([]interface{}{1, 2, 3, 4})
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.EqualValues(t, []interface{}{4, 3, 2, 1}, out)
 
 	out, err = Reverse([]int{1, 2, 3, 4})
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.EqualValues(t, []interface{}{4, 3, 2, 1}, out)
 }
 
@@ -204,7 +205,7 @@ func TestMerge(t *testing.T) {
 	expected := map[string]interface{}{}
 
 	out, err := Merge(dst, src)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.EqualValues(t, expected, out)
 
 	dst = map[string]interface{}{"a": 4, "c": 5}
@@ -214,7 +215,7 @@ func TestMerge(t *testing.T) {
 	}
 
 	out, err = Merge(dst, src)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.EqualValues(t, expected, out)
 
 	dst = map[string]interface{}{"a": 4, "c": 5}
@@ -225,7 +226,7 @@ func TestMerge(t *testing.T) {
 	}
 
 	out, err = Merge(dst, src, src2)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.EqualValues(t, expected, out)
 
 	dst = map[string]interface{}{"a": false, "c": 5}
@@ -236,7 +237,7 @@ func TestMerge(t *testing.T) {
 	}
 
 	out, err = Merge(dst, src, src2)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.EqualValues(t, expected, out)
 
 	dst = map[string]interface{}{"a": true, "c": 5}
@@ -252,7 +253,7 @@ func TestMerge(t *testing.T) {
 	}
 
 	out, err = Merge(dst, src, src2)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.EqualValues(t, expected, out)
 
 	dst = map[string]interface{}{
@@ -277,7 +278,7 @@ func TestMerge(t *testing.T) {
 	}
 
 	out, err = Merge(dst, src)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.EqualValues(t, expected, out)
 }
 
@@ -351,7 +352,7 @@ func TestLessThan(t *testing.T) {
 
 func TestSort(t *testing.T) {
 	out, err := Sort("", 42)
-	assert.Error(t, err)
+	require.Error(t, err)
 	assert.Nil(t, out)
 
 	data := []struct {
@@ -464,7 +465,7 @@ func TestSort(t *testing.T) {
 		d := d
 		t.Run(fmt.Sprintf(`Sort("%s",<%T>)==%#v`, d.key, d.in, d.out), func(t *testing.T) {
 			out, err := Sort(d.key, d.in)
-			assert.NoError(t, err)
+			require.NoError(t, err)
 			assert.EqualValues(t, d.out, out)
 		})
 	}
@@ -541,12 +542,12 @@ func TestFlatten(t *testing.T) {
 
 	for _, d := range data {
 		out, err := Flatten(d.in, d.depth)
-		assert.NoError(t, err)
+		require.NoError(t, err)
 		assert.EqualValues(t, d.expected, out)
 	}
 
 	_, err := Flatten(42, -1)
-	assert.Error(t, err)
+	require.Error(t, err)
 }
 
 func BenchmarkFlatten(b *testing.B) {
